import * as React from "react";
import Stripe from "stripe";
export interface SharedPlanUser {
    stripeCustomer: string;
    createdAt: number;
    email: string;
    name?: string;
    action?: string;
    role: "owner" | "manager" | "user";
    sharedSubscriptionId: string;
}
export declare enum BillingMetadata {
    "billing_match_country_currency" = "billing_match_country_currency",
    "billing_shared_subscription_id" = "billing_shared_subscription_id",
    "billing_shared_subscription_role" = "billing_shared_subscription_role",
    "billing_shared_subscription_owner" = "billing_shared_subscription_owner",
    "billing_support_shared_subscriptions" = "billing_support_shared_subscriptions"
}
export declare enum RecurrenceTypes {
    "Yearly" = "Yearly",
    "Every 6 months" = "Every 6 months",
    "Every 3 months" = "Every 3 months",
    "Monthly" = "Monthly",
    "Weekly" = "Weekly",
    "Daily" = "Daily"
}
export declare enum IntervalType {
    "day" = "day",
    "week" = "week",
    "month" = "month",
    "year" = "year"
}
export declare enum NormalizedIntervalType {
    "yearly" = "yearly",
    "quarterly" = "quarterly",
    "monthly" = "monthly",
    "daily" = "daily"
}
export interface Price extends Stripe.Price {
    product: Stripe.Product;
}
export interface SubscriptionItem extends Stripe.SubscriptionItem {
    price: Price;
}
export interface LatestInvoice extends Stripe.Invoice {
    payment_intent: Stripe.PaymentIntent;
}
export interface Subscription extends Stripe.Subscription {
    customer: Stripe.Customer;
    items: Stripe.ApiList<SubscriptionItem>;
    latest_invoice: LatestInvoice;
}
export interface ModalOptions {
    maskClassName?: string;
    showPromotionCodeInput?: boolean;
    showPricingSummary?: boolean;
}
export interface BillingOptions {
    productPageUrl?: string;
    termsAndConditionsUrl?: string;
    privacyPolicyUrl?: string;
    showTermsAndConditions?: boolean;
    showPrivacyPolicy?: boolean;
    cancelSubscription: {
        showModal: boolean;
        cancelMessage: string;
    };
}
export interface UseProductsOptions {
    defaultCurrency?: string;
    defaultRecurrence?: RecurrenceTypes;
    modal: ModalOptions;
    normalizePriceOnRecurrence: NormalizedIntervalType;
    signIn: () => void;
    onPaymentSuccessful: () => void;
    onPaymentError: () => void;
}
export interface SelectedPricing extends Stripe.Price {
    currencyObject: Currency;
    onSelectPricing: () => void;
    updateQuantity: () => void;
    quantity: number;
    priceInteger: number | React.ReactNode;
    priceDecimal: number | React.ReactNode;
    priceFormatted: string | React.ReactNode;
    price: string | React.ReactNode;
    pricingRecurrence: string | React.ReactNode;
    billingRecurrence: string | React.ReactNode;
    billedPrice: string | React.ReactNode;
}
export interface Currency {
    id: string;
    symbol: string | React.ReactNode;
    name: string | React.ReactNode;
    decimal_digits: number;
    code: string | React.ReactNode;
}
export interface PricingFilter {
    currency: {
        selectedCurrency: Currency;
        availableCurrencies: Currency[];
        setCurrency: (Currency: any) => void;
    };
    recurrence: {
        selectedRecurrence: Recurrence;
        availableRecurrences: Recurrence[];
        setRecurrence: (Recurrence: any) => void;
    };
}
export interface Product extends Stripe.Product {
    pricings: Price[];
    selectedPricing: SelectedPricing;
}
export interface Recurrence {
    name: string | React.ReactNode;
    interval: string | React.ReactNode;
    interval_count: number;
}
declare type Invoice = Stripe.Invoice;
export declare type PaymentIntent = Stripe.PaymentIntent;
export interface PaymentMethod extends Stripe.PaymentMethod {
    customer: Stripe.Customer;
}
export interface Coupon {
    id: string;
    object: string;
    amount_off: number;
    created: number;
    currency: string;
    duration: string;
    duration_in_months: any;
    livemode: boolean;
    max_redemptions: any;
    metadata: any;
    name: string;
    percent_off: any;
    redeem_by: any;
    times_redeemed: number;
    valid: boolean;
}
export interface Customer {
    id: string;
    address?: string | React.ReactNode;
    balance?: number;
    created?: number;
    currency?: string | React.ReactNode;
    default_source?: string | React.ReactNode;
    description?: string | React.ReactNode;
    discount?: string | React.ReactNode;
    email?: string | React.ReactNode;
    livemode?: boolean;
    metadata?: any;
    name?: string | React.ReactNode;
    phone?: string | React.ReactNode;
    shipping?: string | React.ReactNode;
    paymentMethods?: PaymentMethod[];
    subscriptions?: Subscription[];
    invoices?: Invoice[];
}
export interface Pricing {
    id: string;
    active: boolean;
    currency: string | Currency;
    billing_scheme?: string;
    livemode?: boolean;
    lookup_key?: string;
    metadata?: {};
    nickname?: string;
    product?: string;
    recurring: {
        aggregate_usage: string;
        interval: string | React.ReactNode;
        interval_count: number;
        trial_period_days: number;
        usage_type: string;
    };
    tiers_mode?: string;
    transform_quantity?: string;
    type?: string;
    unit_amount: number;
    unit_amount_decimal: number;
}
export {};
